@@ -38,6 +38,7 @@ Usage::
         DescribeHostReservationsPaginator,
         DescribeHostsPaginator,
         DescribeIamInstanceProfileAssociationsPaginator,
+        DescribeImagesPaginator,
         DescribeImportImageTasksPaginator,
         DescribeImportSnapshotTasksPaginator,
         DescribeInstanceCreditSpecificationsPaginator,
@@ -243,6 +244,7 @@ Usage::
     describe_host_reservations_paginator: DescribeHostReservationsPaginator = client.get_paginator("describe_host_reservations")
     describe_hosts_paginator: DescribeHostsPaginator = client.get_paginator("describe_hosts")
     describe_iam_instance_profile_associations_paginator: DescribeIamInstanceProfileAssociationsPaginator = client.get_paginator("describe_iam_instance_profile_associations")
+    describe_images_paginator: DescribeImagesPaginator = client.get_paginator("describe_images")
     describe_import_image_tasks_paginator: DescribeImportImageTasksPaginator = client.get_paginator("describe_import_image_tasks")
     describe_import_snapshot_tasks_paginator: DescribeImportSnapshotTasksPaginator = client.get_paginator("describe_import_snapshot_tasks")
     describe_instance_credit_specifications_paginator: DescribeInstanceCreditSpecificationsPaginator = client.get_paginator("describe_instance_credit_specifications")
@@ -378,6 +380,7 @@ from .paginator import (
     DescribeHostReservationsPaginator,
     DescribeHostsPaginator,
     DescribeIamInstanceProfileAssociationsPaginator,
+    DescribeImagesPaginator,
     DescribeImportImageTasksPaginator,
     DescribeImportSnapshotTasksPaginator,
     DescribeInstanceCreditSpecificationsPaginator,
@@ -561,6 +564,7 @@ __all__ = (
     "DescribeHostReservationsPaginator",
     "DescribeHostsPaginator",
     "DescribeIamInstanceProfileAssociationsPaginator",
+    "DescribeImagesPaginator",
     "DescribeImportImageTasksPaginator",
     "DescribeImportSnapshotTasksPaginator",
     "DescribeInstanceCreditSpecificationsPaginator",
